%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Cover Corporate Identity v1.1.0
%
% LaTeX class for article style documents in Cover's Corporate Idenity
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cover-article}[2016/08/29 v1.1.0 Cover Article]

\newcommand{\backgroundimage}{\AddToShipoutPicture{\includegraphics{assets/document_template_external}}}

\DeclareOption{external}{}
\DeclareOption{internal}{\renewcommand{\backgroundimage}{\AddToShipoutPicture{\includegraphics{assets/document_template_internal}}}}
\DeclareOption{internal-legal}{\renewcommand{\backgroundimage}{\AddToShipoutPicture{\includegraphics{assets/document_template_internal_legal}}}}
\DeclareOption{empty}{\renewcommand{\backgroundimage}{}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\LoadClass[a4paper,10pt]{article}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PDF Settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[colorlinks=false]{hyperref}

% No borders around links and set PDF application
\hypersetup{%
  pdfborder={0 0 0},
  pdfcreator={Cover Corporate Identity v1.1.0}
}

% renew \author command to add author to pdf metadata
\renewcommand{\author}[1]{%
  \gdef\@author{#1}%
  \hypersetup{%
    pdfauthor={\@author}
  }
}

% renew \title command to add title to pdf metadata
\renewcommand{\title}[1]{%
  \gdef\@title{#1}%
  \hypersetup{%
    pdftitle={\@title}
  }
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Page Settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[usenames,dvipsnames,svgnames,table]{xcolor}
\RequirePackage{graphicx}   % Images
\RequirePackage{eso-pic}    % Watermark
\RequirePackage[top=4cm,right=2.5cm,bottom=3.5cm,left=2.5cm]{geometry}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load fonts and characters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{mathpazo} % Load palatino
\linespread{1.05}         % Palatino needs more leading (space between lines)
\RequirePackage{FiraSans} % Load Fira as SS
\RequirePackage{FiraMono} % Load Fira as TT
\normalfont
\RequirePackage[T1]{fontenc}
\RequirePackage{sectsty}
\RequirePackage{titling}
\allsectionsfont{\sffamily}
\renewcommand{\maketitlehooka}{\sffamily}
\RequirePackage{parskip}

% Square

\RequirePackage{amsmath}

\DeclareFontFamily{U}{mathb}{}
\DeclareFontShape{U}{mathb}{m}{n}{
  <-5.5> mathb5
  <5.5-6.5> mathb6
  <6.5-7.5> mathb7
  <7.5-8.5> mathb8
  <8.5-9.5> mathb9
  <9.5-11.5> mathb10
  <11.5-> mathbb12
}{}
\DeclareRobustCommand{\sqcdot}{%
  \text{\,\usefont{U}{mathb}{m}{n}\symbol{"0D}}%
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Custom header/footer settings
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Headers for custom page numbers
\RequirePackage{zref-abspage,zref-lastpage}
\RequirePackage{fancyhdr}

% Lastpage counter for fancy page numbers

\newcommand*{\iffancylastpage}{%
  \ifnum\zref@extractdefault{LastPage}{abspage}{-1}%
      =\numexpr\value{abspage}+1\relax
    \expandafter\@firstoftwo
  \else
    \expandafter\@secondoftwo
  \fi
}%

% Set fancy page numbers

\fancyhf{} % clear all header and footers
\renewcommand{\headrulewidth}{0pt} % remove the header rule

\fancyfoot[R]{%
  \iffancylastpage{\thepage\sqcdot}{\thepage}%
}
\pagestyle{fancy}

% Overwrite maketitle to stop it from being stupid with page styles
\renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    \thispagestyle{fancy}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Custom colors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% \definecolor{coverRed}{RGB}{200,16,46}
\definecolor{coverRed}{cmyk}{0.02,1,0.85,0.06}
% \definecolor{coverLG}{RGB}{218,218,218}
\definecolor{coverLG}{cmyk}{0,0,0,0.2}
% \definecolor{coverDG}{RGB}{102,102,102}
\definecolor{coverDG}{cmyk}{0,0,0,0.7}
% \definecolor{coverBlue}{RGB}{54,116,157}
\definecolor{coverBlue}{cmyk}{0.83, 0.39, 0.15, 0.13}
% \definecolor{coverGreen}{RGB}{0,173,80}
\definecolor{coverGreen}{cmyk}{0.87, 0.0, 0.91, 0.0}
% \definecolor{coverYellow}{RGB}{215,200,38}
\definecolor{coverYellow}{cmyk}{0.7, 0.1, 0.89, 0.10}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set background image
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\backgroundimage

\endinput
